@@ -26,13 +26,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
  */
 
-#ifndef _PVIDFILE
-#define _PVIDFILE
+#ifndef PTLIB_PVIDFILE_H
+#define PTLIB_PVIDFILE_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -124,4 +124,7 @@ class PYUVFile : public PVideoFile
 #endif
 #endif
 
-#endif // P_VIDFILE
+#endif // PTLIB_PVIDFILE_H
+
+
+// End Of File ///////////////////////////////////////////////////////////////
