@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21788 $
+ * $Revision: 22742 $
  * $Author: rjongbloed $
- * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
+ * $Date: 2009-05-28 00:13:15 +0000 (Thu, 28 May 2009) $
  */
 
 #ifndef PTLIB_OBJECT_H
@@ -60,6 +60,36 @@
 #include <sstream>
 
 
+#define P_REMOVE_VIRTUAL_INTERNAL_BASE(fn) __inline virtual struct ptlib_virtual_function_changed_or_removed ****** fn { return 0; }
+
+#if defined(_MSC_VER)
+  #if _MSC_VER < 1310
+    #define P_DEPRECATED
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) P_REMOVE_VIRTUAL_INTERNAL_BASE(fn)
+  #elif _MSC_VER < 1400
+    #define P_DEPRECATED __declspec(deprecated)
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) __inline virtual __declspec(deprecated) type fn body
+  #else
+    #define P_DEPRECATED __declspec(deprecated)
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) __inline virtual __declspec(deprecated("Virtual function signature changed or function deprecated")) type fn body
+  #endif
+#elif defined(__GNUC__)
+  #if __GNUC__ < 4
+    #define P_DEPRECATED
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) P_REMOVE_VIRTUAL_INTERNAL_BASE(fn)
+  #else
+    #define P_DEPRECATED __attribute__((deprecated))
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) __attribute__((warn_unused_result)) __attribute__((deprecated)) P_REMOVE_VIRTUAL_INTERNAL_BASE(fn)
+  #endif
+#else
+    #define P_DEPRECATED
+    #define P_REMOVE_VIRTUAL_INTERNAL(type, fn, body) P_REMOVE_VIRTUAL_INTERNAL_BASE(fn)
+#endif
+
+#define P_REMOVE_VIRTUAL_VOID(fn)       P_REMOVE_VIRTUAL_INTERNAL(void, fn, {})
+#define P_REMOVE_VIRTUAL(type, fn, ret) P_REMOVE_VIRTUAL_INTERNAL(type, fn, { return ret; })
+
+
 // P_USE_INTEGER_BOOL is the default and gives the old behaviour (it
 // is also used for C translation units).
 // without P_USE_INTEGER_BOOL, the ANSI C++ bool is used.
