@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21314 $
- * $Author: dsandras $
- * $Date: 2008-10-13 17:36:57 +0000 (Mon, 13 Oct 2008) $
+ * $Revision: 23120 $
+ * $Author: rjongbloed $
+ * $Date: 2009-07-21 23:31:08 +0000 (Tue, 21 Jul 2009) $
  */
 
 #ifdef __GNUC__
@@ -719,7 +719,7 @@ PBoolean PSTUNClient::CreateSocket(PUDPSocket * & socket, const PIPSocket::Addre
       break;
 
     case SymmetricNat :
-      if (singlePortInfo.basePort == 0 || singlePortInfo.basePort > singlePortInfo.maxPort)
+      if (localPort == 0 && (singlePortInfo.basePort == 0 || singlePortInfo.basePort > singlePortInfo.maxPort))
       {
         PTRACE(1, "STUN\tInvalid local UDP port range "
                << singlePortInfo.currentPort << '-' << singlePortInfo.maxPort);
