@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22614 $
+ * $Revision: 23336 $
  * $Author: rjongbloed $
- * $Date: 2009-05-14 01:58:18 +0000 (Thu, 14 May 2009) $
+ * $Date: 2009-09-05 01:02:14 +0000 (Sat, 05 Sep 2009) $
  */
 
 #include <ptlib.h>
@@ -1546,7 +1546,7 @@ PProcess::PProcess(const char * manuf, const char * name,
   , m_library(library)
 {
   activeThreads.DisallowDeleteObjects();
-  activeThreads.SetAt((uintptr_t)GetCurrentThreadId(), this);
+  activeThreads.SetAt(_hptr(GetCurrentThreadId()), this);
 
   PProcessInstance = this;
 
@@ -1910,7 +1910,7 @@ PThread * PThread::Current()
   PProcess & process = PProcess::Current();
 
   process.activeThreadMutex.Wait();
-  PThread * thread = process.activeThreads.GetAt((uintptr_t)GetCurrentThreadId());
+  PThread * thread = process.activeThreads.GetAt(_hptr(GetCurrentThreadId()));
   process.activeThreadMutex.Signal();
 
   if (thread == NULL)
@@ -2208,21 +2208,21 @@ PReadWriteMutex::~PReadWriteMutex()
 PReadWriteMutex::Nest * PReadWriteMutex::GetNest() const
 {
   PWaitAndSignal mutex(nestingMutex);
-  return nestedThreads.GetAt(POrdinalKey((INT)PThread::GetCurrentThreadId()));
+  return nestedThreads.GetAt(POrdinalKey(_hptr(PThread::GetCurrentThreadId())));
 }
 
 
 void PReadWriteMutex::EndNest()
 {
   nestingMutex.Wait();
-  nestedThreads.RemoveAt(POrdinalKey((INT)PThread::GetCurrentThreadId()));
+  nestedThreads.RemoveAt(POrdinalKey(_hptr(PThread::GetCurrentThreadId())));
   nestingMutex.Signal();
 }
 
 
 PReadWriteMutex::Nest & PReadWriteMutex::StartNest()
 {
-  POrdinalKey threadId = (INT)PThread::GetCurrentThreadId();
+  POrdinalKey threadId = _hptr(PThread::GetCurrentThreadId());
 
   nestingMutex.Wait();
 
