@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22295 $
+ * $Revision: 23336 $
  * $Author: rjongbloed $
- * $Date: 2009-03-26 00:31:31 +0000 (Thu, 26 Mar 2009) $
+ * $Date: 2009-09-05 01:02:14 +0000 (Sat, 05 Sep 2009) $
  */
 
 #define _CONFIG_CXX
@@ -49,7 +49,7 @@
 #define	EXTENSION		".ini"
 #define	ENVIRONMENT_CONFIG_STR	"/\~~environment~~\/"
 
-#ifdef P_MACOSX
+#if defined(P_MACOSX) || defined(P_SOLARIS) || defined(P_FREEBSD)
 #define environ (NULL)
 #endif
 
